#!/usr/bin/env python
'''
This file contains Python command example for the ALL PORT COUNTER DUMP module.
Python commands syntax is very similar to the Switch SDK APIs. 
You can learn more about each command and its parameters by reading the SwitchX API Reference Manual.

The example below demonstrates the configuration of different port attributes.
'''
import sys
import os
sys.path.append('/usr/lib/python2.7/dist-packages/python_sdk_api/')
sys.path.append('/usr/lib/python2.7/site-packages/python_sdk_api/')
sys.path.append('/usr/local/lib/python2.7/dist-packages/python_sdk_api/')
sys.path.append('/usr/local/lib/python2.7/site-packages/python_sdk_api/')

from sx_api import *

ERR_FILE_LOCATION = '/tmp/python_err_log.txt'

def check_vport(port):
    PORT_TYPE_VPORT = 2
    PORT_TYPE_OFFSET = 28
    PORT_TYPE_MASK = 0xF0000000
    port_type = (port & PORT_TYPE_MASK) >> PORT_TYPE_OFFSET
    return port_type & PORT_TYPE_VPORT


def print_all_attr_from_a_struct(struct):
    for attr in dir(struct):
        if not attr.startswith("__") and not attr == "this":
            print "\t%s = %s" % (attr, getattr(struct, attr))

print "[+] Redirecting stderr to: %s" % ERR_FILE_LOCATION
file_exist = os.path.isfile(ERR_FILE_LOCATION)
sys.stderr = open(ERR_FILE_LOCATION, 'w')
if not file_exist:
    os.chmod(ERR_FILE_LOCATION, 0o777);
    
print "[+] opening sdk"
rc, handle = sx_api_open(None)
print ("sx_api_open handle:0x%x , rc %d " % ( handle, rc) )
if (rc != 0):
    print "Failed to open api handle.\nPlease check that SDK is running."
    exit()

port_cnt_p = new_uint32_t_p()
port_attributes_list = new_sx_port_attributes_t_arr(64)
port_attributes = sx_port_attributes_t()
uint32_t_p_assign(port_cnt_p,64)
rc = sx_api_port_device_get(handle, 1 , 0, port_attributes_list,  port_cnt_p)
port_cnt = uint32_t_p_value(port_cnt_p)
print ("sx_api_port_device_get port_cnt:%d , rc %d " % (port_cnt, rc) )
if (rc != 0):
    print "An error was found in sx_api_port_device_get.\nThe example will exit"
    exit()
print ("=================================================================")
for i in range(0,port_cnt):
    port_attributes = sx_port_attributes_t_arr_getitem(port_attributes_list,i)
    if check_vport(int(port_attributes.log_port)):
        continue
    cnt = sx_port_cntr_cli_t()
    rc = sx_api_port_counter_cli_get(handle, SX_ACCESS_CMD_READ, port_attributes.log_port, cnt)
    print ("[%d]: log_port:0x%x local_port:%d label_port:%d\n" % (i,port_attributes.log_port, port_attributes.port_mapping.local_port, port_attributes.port_mapping.module_port + 1,))
    print ("sx_api_port_counter_cli_get log_port 0x%x , rc %d " % ( port_attributes.log_port, rc) )
    print_all_attr_from_a_struct(cnt)
    print ("=================================================================\n")


